@@ -59,12 +59,12 @@ class WebBrowser:
     self.chrome_options.add_experimental_option('prefs', self.preferences)
 
   def getConfig(self):
-    self.logger.debug("Current Path: %s" % self.current_path)
-    self.logger.debug("OS Platform: %s, %s" % (self.os_platform[0],self.os_platform[1]))
+    self.logger.info("Current Path: %s" % self.current_path)
+    self.logger.info("OS Platform: %s, %s" % (self.os_platform[0],self.os_platform[1]))
 
-    self.logger.debug("Google Chrome: %s" % self.chrome_exe)
-    self.logger.debug("Google Chrome Version: %s" % self.chrome_version)
-    self.logger.debug("Chrome Driver: %s" % self.chromedriver_exe)
+    self.logger.info("Google Chrome: %s" % self.chrome_exe)
+    self.logger.info("Google Chrome Version: %s" % self.chrome_version)
+    self.logger.info("Chrome Driver: %s" % self.chromedriver_exe)
 
   def getChromeVersion(self,filename):
     parser = win32com.client.Dispatch("Scripting.FileSystemObject")
